@@ -7,7 +7,7 @@
  * which provides users with simple management of email filter groups.
  * 
  * @copyright Copyright (c) 2002-2007 O'Shaughnessy Evans <shaug-sqml @ wumpus.org>
- * @version $Id: lib.php,v 1.12 2007/09/11 23:35:21 shaug Exp $
+ * @version $Id: lib.php,v 1.15 2007/09/13 20:00:17 shaug Exp $
  * @license http://opensource.org/licenses/artistic-license-2.0.php
  * @package plugins
  * @subpackage spamrule
@@ -29,7 +29,6 @@
  * function sr_ftp_get($path)
  * function sr_ftp_put($path, $data)
  * function sr_syslog($message)
- * function sr_gettext($str)
  * function sr_get_forward()
  * function sr_install_forward($install_forwared)
  */
@@ -56,7 +55,7 @@ function sr_print_header($mesg, $columns)
 {
     global $color;
 
-    $title = _("Options") . ' - '. sr_gettext("Spam Rules");
+    $title = _("Options") . ' - '. _("Spam Rules");
 
     echo <<<EOtable_top
 <br>
@@ -154,7 +153,7 @@ function sr_select_group()
       <th align="left" colspan="3">
         <form action="options.php" method="GET">
 EOheader;
-    print sr_gettext("You may choose one of these options:");
+    print _("You may choose one of these options:");
     echo <<<EOheader
       </th>
     </tr>
@@ -179,46 +178,46 @@ EOheader;
     if ($javascript_on) {
         $update_links .= ' <a href="javascript:void(0)" onclick="subwin'.
          '(\'options.php?action=editlist&list=allowed_recipients\','.
-         ' \'sr_editlist\', 450, 450)">'. sr_gettext("Aliases").
+         ' \'sr_editlist\', 450, 450)">'. _("Aliases").
          '</a><br>';
         $update_links .= ' <a href="javascript:void(0)" onclick="subwin'.
          '(\'options.php?action=editlist&list=allowed_senders\','.
-         ' \'sr_editlist\', 450, 450)">'. sr_gettext("Allowed Senders").
+         ' \'sr_editlist\', 450, 450)">'. _("Allowed Senders").
          '</a><br>';
         $update_links .= ' <a href="javascript:void(0)" onclick="subwin'.
          '(\'options.php?action=editlist&list=blocked_senders\','.
-         ' \'sr_editlist\', 450, 450)">'. sr_gettext("Blocked Senders").
+         ' \'sr_editlist\', 450, 450)">'. _("Blocked Senders").
          '</a><br>';
         $update_links .= ' <a href="javascript:void(0)" onclick="subwin'.
          '(\'options.php?action=editlist&list=subject_passwords\','.
-         ' \'sr_editlist\', 450, 450)">'. sr_gettext("Subject Passwords").
+         ' \'sr_editlist\', 450, 450)">'. _("Subject Passwords").
          '</a><br>';
         $update_links .= ' <a href="javascript:void(0)" onclick="subwin'.
          '(\'options.php?action=editlist&list=blocked_subjects\','.
-         ' \'sr_editlist\', 450, 450)">'. sr_gettext("Blocked Subjects").
+         ' \'sr_editlist\', 450, 450)">'. _("Blocked Subjects").
          '</a><br>';
     }
     else {
         $update_links .= ' <a href="options.php?action=editlist&list='.
-         'allowed_recipients" target="_blank">'. sr_gettext("Aliases").
+         'allowed_recipients" target="_blank">'. _("Aliases").
          '</a><br>';
         $update_links .= ' <a href="options.php?action=editlist&list='.
-         'allowed_senders" target="_blank">'. sr_gettext("Allowed senders").
+         'allowed_senders" target="_blank">'. _("Allowed senders").
          '</a><br>';
         $update_links .= ' <a href="options.php?action=editlist&list='.
-         'blocked_senders" target="_blank">'. sr_gettext("Blocked senders").
+         'blocked_senders" target="_blank">'. _("Blocked senders").
          '</a><br>';
         $update_links .= ' <a href="options.php?action=editlist&list='.
-         'subject_passwords" target="_blank">'. sr_gettext("Subject Passwords").
+         'subject_passwords" target="_blank">'. _("Subject Passwords").
          '</a><br>';
         $update_links .= ' <a href="options.php?action=editlist&list='.
-         'blocked_subjects" target="_blank">'. sr_gettext("Blocked Subjects").
+         'blocked_subjects" target="_blank">'. _("Blocked Subjects").
          '</a><br>';
     }
 
-    $show_label = sr_gettext("Show my current filters");
-    $update_label = sr_gettext("Update my:");
-    $next_label = sr_gettext("Next");
+    $show_label = _("Show my current filters");
+    $update_label = _("Update my:");
+    $next_label = _("Next");
     echo <<<EOend
     <tr bgcolor="$rowcolor" align="left">
       <td>&nbsp;</td>
@@ -271,8 +270,8 @@ function sr_select_filters()
     }
 
     // print out the beginning of the form
-    $col1_label = sr_gettext("Name");
-    $col2_label = sr_gettext("What Does It Do?");
+    $col1_label = _("Name");
+    $col2_label = _("What Does It Do?");
     echo <<<EOheader
     <tr align="left" valign="bottom" bgcolor="{$color[4]}">
       <th><form action="options.php" method="POST"></th>
@@ -287,6 +286,10 @@ EOheader;
     foreach ($SPAMRULE_OPTS['filters'] as $filter => $settings) {
         $n++;
         $rowcolor = $n % 2 ? $color[12] : $color[4];
+	// skip filters that have been disabled in the config files
+	if (is_null($settings)) {
+	    continue;
+	}
         echo "  <tr valign=top bgcolor=\"$rowcolor\">\n" .
              "    <td><input type=checkbox " .
               "name=\"SPAMRULE_OPTS[groups][CUSTOM][filters][]\" " .
@@ -298,14 +301,15 @@ EOheader;
     }
 
     // close out the form
-    $finish_label = sr_gettext("Finish");
+    $finish_label = _("Finish");
+    $reset_label = _("Reset");
     echo <<<EOF
     <tr>
       <td colspan="3"> 
         <br>
         <input type="hidden" name="newgroup" value="CUSTOM">
         <input type="hidden" name="action" value="groups">
-        <input type="submit" name="finish" value="$finish_label"> &nbsp; <input type="reset">
+        <input type="submit" name="finish" value="$finish_label"> &nbsp; <input type="reset" value="$reset_label">
       </td>
     </tr>
     </form>
@@ -381,9 +385,9 @@ function sr_print_subscribed()
 EOrow;
     }
 
-    $sel_label = sr_gettext("You have selected");
-    $sel_label2 = sr_gettext("filters");
-    $none_label = sr_gettext("There is no further information for this group.");
+    $sel_label = _("You have selected");
+    $sel_label2 = _("filters");
+    $none_label = _("There is no further information for this group.");
     if ($filter_summary) {
         echo <<<EOheader
     <tr align="left" bgcolor="{$color[4]}">
@@ -503,9 +507,8 @@ function sr_install_filters($group, $filters)
                                          $data);
     if ($status != TRUE) {
         sr_syslog($results);
-        $err_label1 = sr_gettext("Whoops!  There was trouble installing your ".
-                                 "filters.");
-        $err_label2 = sr_gettext("Here's the message:");
+        $err_label1 = _("Whoops!  There was trouble installing your filters.");
+        $err_label2 = _("Here's the message:");
         echo <<<EOerror
   <p>
   <strong>$err_label1</strong><br>
@@ -573,6 +576,7 @@ function sr_maintain_list($list)
 {
     global $SPAMRULE_OPTS, $color;
     sqgetGlobalVar('SPAMRULE_OPTS', $SPAMRULE_OPTS, SQ_SESSION);
+    $ftpdata = '';
     $ignored = array();
     $patterns = array();
     $status = FALSE;
@@ -585,12 +589,17 @@ function sr_maintain_list($list)
 
     // get the list of current patterns, which will be modified as
     // appropriate by our lists of patterns to add and delete
-    list($status, $patterns) = sr_ftp_get($SPAMRULE_OPTS[$list]['file']);
+    list($status, $ftpdata) = sr_ftp_get($SPAMRULE_OPTS[$list]['file']);
+    if ($status === FALSE) {
+        print _("Sorry, there was a problem downloading your list:").
+	      '  '. $ftpdata;
+        return;
+    }
 
     // get rid of duplicate patterns, make sure there are no empty ones,
     // then get rid of regex escapes and anchors we added when saving
-    if ($status === TRUE && !empty($patterns)) {
-        $patterns = array_unique($patterns);
+    if (!empty($ftpdata)) {
+        $patterns = array_unique($ftpdata);
         foreach ($patterns as $k => $v) {
             $orig = $v;
             $v = trim($v);
@@ -647,9 +656,6 @@ function sr_maintain_list($list)
             }
         }
     }
-    else {
-        $patterns = array();
-    }
 
     // get the requested changes
     sqgetGlobalVar('sr_del_patterns', $delpats, SQ_FORM);
@@ -714,12 +720,12 @@ function sr_maintain_list($list)
     // if we ignored any entries in the file, warn the user about them.
     if (!empty($ignored)) {
         $ignored_mesg = implode('</tt></li><li><tt>', $ignored);
-        $warning_msg = sr_gettext("Warning:  We found some entries in your ".
-                                  "list that don't look like email addresses.".
-                                  "  In the future, please include just the ".
-                                  "&quot;user@domain&quot; part of an email ".
-                                  "address, without any extra comments, real ".
-                                  "name, or quotes.  These have been ignored:");
+        $warning_msg = _("Warning:  We found some entries in your list that ".
+                         "don't look like email addresses.  In the future, ".
+                         "please include just the &quot;user@domain&quot; ".
+			 "part of an email address, without any extra ".
+			 "comments, real name, or quotes.  These have been ".
+			 "ignored:");
         echo <<<EOwarning
 
 <tr valign="top" bgcolor="$color[12]"><td colspan="3">
@@ -735,8 +741,8 @@ EOwarning;
     echo "<form action=\"options.php?action=editlist&list=$list\" ".
          "method=POST>\n";
     if ($patterns) {
-        $remove_label = sr_gettext("Remove?");
-        $addr_label = sr_gettext("Address");
+        $remove_label = _("Remove?");
+        $addr_label = _("Address");
         echo <<<EOformtop
 
   <tr valign="top" bgcolor="$color[4]">
@@ -764,9 +770,13 @@ EOrow;
 
     $n++;
     $rowcolor = $n % 2 ? $color[12] : $color[4]; 
-    $default = $patterns ? '' : $SPAMRULE_OPTS[$list]['default'];
-    $add_label = sr_gettext("Add a new entry:");
-    $update_label = sr_gettext("Update");
+    $default = $patterns
+               ? ''
+	       : isset($SPAMRULE_OPTS[$list]['default'])
+                 ? $SPAMRULE_OPTS[$list]['default']
+		 : '';
+    $add_label = _("Add a new entry:");
+    $update_label = _("Update");
     echo <<<EOform
   <tr valign="top" bgcolor="$rowcolor">
     <td colspan="3"><br><p>$add_label
@@ -811,13 +821,12 @@ function sr_ftp_get($path)
 
     $ftphost = $SPAMRULE_OPTS['ftphost'];
     if (!$ftphost) {
-        return array(FALSE, sr_gettext("Sorry, but this plugin is not ".
-                            "completely set up.  Please contact your ".
-                            "System Administrator about configuring the ".
-                            "Spam Rules plugin."));
+        return array(FALSE, _("Sorry, but this plugin is not completely set ".
+	                      "up.  Please contact your support department ".
+			      "about configuring the Spam Rules plugin."));
     }
     if (!$path) {
-        return array(FALSE, sr_gettext("no file was given to upload"));
+        return array(FALSE, _("no file was given to upload"));
     }
 
     // decrypt the user's password so we can pass it to the ftp site
@@ -825,25 +834,26 @@ function sr_ftp_get($path)
     $password = OneTimePadDecrypt($key, $onetimepad);
 
     // upload the file to the user's home
-    $ftp = ftp_connect($ftphost);
-    if (!$ftp) {
-        return array(FALSE, sr_gettext("cannot connect to"). " $ftphost".
-                            ($php_errormsg ? ": $php_errormsg" : ''));
+    $ftp = @ftp_connect($ftphost);
+    if ($ftp === FALSE) {
+        return array(FALSE, _("cannot connect to"). " $ftphost".
+                            (isset($php_errormsg) ? ": $php_errormsg" : ''));
     }
 
-    $stat = ftp_login($ftp, $username, $password);
-    if (!$stat) {
-        return array(FALSE, sr_gettext("cannot log in to"). " $ftphost".
-                            ($php_errormsg ? ": $php_errormsg" : ''));
+    $status = @ftp_login($ftp, $username, $password);
+    if ($status === FALSE) {
+        return array(FALSE, _("cannot log in to"). " $ftphost".
+                            (isset($php_errormsg) ? ": $php_errormsg" : ''));
     }
 
-    if (! @ftp_chdir($ftp, dirname($path))) {
+    if (@ftp_chdir($ftp, dirname($path)) === FALSE) {
         return array(FALSE, '');
     }
 
     $file = basename($path);
-    if (! @ftp_size($ftp, $file)) {
-        return array(FALSE, sr_gettext("cannot read"). " $file: $php_errormsg");
+    if (! @ftp_size($ftp, $file) === -1) {
+        return array(FALSE, _("cannot read"). " $file".
+                            (isset($php_errormsg) ? ": $php_errormsg" : ''));
     }
 
     // create a local temp file to store the rules
@@ -887,14 +897,13 @@ function sr_ftp_put($path, $data)
 
     $ftphost = $SPAMRULE_OPTS['ftphost'];
     if (!$ftphost) {
-        return array(FALSE, sr_gettext("Sorry, but this plugin is not ".
-                            "completely set up.  Please contact your ".
-                            "System Administrator about configuring the ".
-                            "Spam Rules plugin."));
+        return array(FALSE, _("Sorry, but this plugin is not completely set ".
+	                      "up.  Please contact your support department ".
+			      "about configuring the Spam Rules plugin."));
     }
 
     if (empty($path)) {
-        return array(FALSE, sr_gettext("no file was given to upload"));
+        return array(FALSE, _("no file was given to upload"));
     }
 
     // decrypt the user's password so we can pass it to the ftp site
@@ -904,19 +913,18 @@ function sr_ftp_put($path, $data)
     // upload the file to the user's home
     $ftp = ftp_connect($ftphost);
     if (!$ftp) {
-        return array(FALSE, sr_gettext("cannot connect to"). " $ftphost".
-                            ($php_errormsg ? ": $php_errormsg" : ''));
+        return array(FALSE, _("cannot connect to"). " $ftphost".
+                            (isset($php_errormsg) ? ": $php_errormsg" : ''));
     }
 
-    $stat = ftp_login($ftp, $username, $password);
-    if (!$stat) {
-        return array(FALSE, sr_gettext("cannot log in to"). " $ftphost".
-                            ($php_errormsg ? ": $php_errormsg" : ''));
+    $status = ftp_login($ftp, $username, $password);
+    if (!$status) {
+        return array(FALSE, _("cannot log in to"). " $ftphost".
+                            (isset($php_errormsg) ? ": $php_errormsg" : ''));
     }
 
     // if there is data to upload, write it to a temporary file and upload
     // its contents
-    print "we gots some writing to do:  <pre>$data</pre><br>\n";
     if ($data) {
         // create a file w/the new rules
         $temp = tmpfile();
@@ -927,7 +935,6 @@ function sr_ftp_put($path, $data)
         // doesn't exist
         $dir = dirname($path);
         $dirs = preg_split('/[\\/\\\]+/', $dir, -1, PREG_SPLIT_NO_EMPTY);
-	print "examining $dir...<br>\n";
         foreach ($dirs as $d) {
             if ($d == '.') {
                 continue;
@@ -939,8 +946,8 @@ function sr_ftp_put($path, $data)
                 if (!(@ftp_mkdir($ftp, $d) && @ftp_site($ftp, "chmod 0700 $d")
                      && @ftp_chdir($ftp, $d))) {
                     @ftp_close($ftp);
-                    return array(FALSE, sr_gettext("error creating"). " $dir".
-                                 ($php_errormsg ? ": $php_errormsg" : ''));
+                    return array(FALSE, _("error creating"). " $dir".
+                               (isset($php_errormsg) ? ": $php_errormsg" : ''));
                 }
             }
         }
@@ -953,11 +960,11 @@ function sr_ftp_put($path, $data)
         */
 
         $file = basename($path);
-        $stat = ftp_fput($ftp, $file, $temp, FTP_ASCII);
-        if (!$stat) {
+        $status = ftp_fput($ftp, $file, $temp, FTP_ASCII);
+        if (!$status) {
             @ftp_close($ftp);
-            return array(FALSE, sr_gettext("error changing"). " $cwd/$file".
-                                ($php_errormsg ? ": $php_errormsg" : ''));
+            return array(FALSE, _("error changing"). " $cwd/$file".
+                               (isset($php_errormsg) ? ": $php_errormsg" : ''));
         }
         @ftp_site($ftp, "chmod 0600 $file");
         fclose($temp);
@@ -965,18 +972,18 @@ function sr_ftp_put($path, $data)
     // otherwise delete the remote file (we don't want to leave an empty file)
     else {
         if (@ftp_size($ftp, $path) > 0) {
-            $stat = @ftp_delete($ftp, $path);
-            if (!$stat) {
+            $status = @ftp_delete($ftp, $path);
+            if (!$status) {
                 @ftp_close($ftp);
-                return array(FALSE, sr_gettext("error removing"). " $path".
-                                    ($php_errormsg ? ": $php_errormsg" : ''));
+                return array(FALSE, _("error removing"). " $path".
+                               (isset($php_errormsg) ? ": $php_errormsg" : ''));
             }
         }
     }
 
     @ftp_close($ftp);
 
-    return array(TRUE);
+    return array(TRUE, NULL);
 }
 
 
@@ -999,31 +1006,6 @@ function sr_syslog($message)
 }
 
 
-/**
- * sr_gettext($str)
- * 
- * Switch the gettext domain to spamrule's before reading the localized
- * version of a string, then switch the translation domain back to squirrelmail
- * 
- * @param string $str  string to be translated
- * 
- * @returns string containing gettext-translated text
- */
-function sr_gettext($str)
-{
-    $localstr = '';
-
-    //bindtextdomain('spamrule', SM_PATH. 'plugins/spamrule/locale');
-    textdomain('spamrule');
-
-    $localstr = _($str);
-
-    //bindtextdomain('squirrelmail', SM_PATH. 'locale');
-    textdomain('squirrelmail');
-
-    return $localstr;
-}
-
 /**
  * sr_install_forward($install_filter)
  * 
@@ -1049,16 +1031,23 @@ function sr_install_forward($install_filter)
 
     $changed = FALSE;
     $data = '';
+    $ftpdata = '';
     $forward = '';
     $has_filter = FALSE;
     $status = FALSE;
 
     // download and install the forward file
-    list($status, $forward) = sr_ftp_get($SPAMRULE_INSTALL['forward_file']);
+    list($status, $ftpdata) = sr_ftp_get($SPAMRULE_INSTALL['forward_file']);
+    if ($status === FALSE) {
+        print _("Sorry, there was a problem downloading your forward file:").
+	      '  '. $ftpdata;
+        return;
+    }
 
     // search through the forward file and look for an entry matching
     // the filter string or explicit storage to the local inbox.
-    if ($status === TRUE && !empty($forward)) {
+    if (!empty($ftpdata)) {
+	$forward = $ftpdata;
         reset($forward);
         while (list($i, $f) = each($forward)) {
             //$f = trim($f);
@@ -1102,6 +1091,6 @@ function sr_install_forward($install_filter)
         return sr_ftp_put($SPAMRULE_INSTALL['forward_file'], $data);
     }
     else {
-        return array(TRUE);
+        return array(TRUE, NULL);
     }
 }
