@@ -7,7 +7,7 @@
  * which provides users with simple management of email filter groups.
  * 
  * @copyright Copyright (c) 2002-2007 O'Shaughnessy Evans <shaug-sqml @ wumpus.org>
- * @version $Id: options.php,v 1.6 2007/09/11 23:39:35 shaug Exp $
+ * @version $Id: options.php,v 1.9 2007/09/13 19:59:21 shaug Exp $
  * @license http://opensource.org/licenses/artistic-license-2.0.php
  * @package plugins
  * @subpackage spamrule
@@ -15,16 +15,16 @@
 
 
 // load init scripts for SquirrelMail 1.5 or 1.4
-if (file_exists('../../include/init.php'))  {
+if (file_exists('../../include/init.php')) {
     require('../../include/init.php');
 }
-else if (file_exists('../../include/validate.php'))  {
+else if (file_exists('../../include/validate.php')) {
     if (!defined('SM_PATH')) {
         define('SM_PATH', '../../');
     }
     include_once(SM_PATH . 'include/validate.php');
 } 
-else if (file_exists('../../src/validate.php'))  {
+else if (file_exists('../../src/validate.php')) {
     chdir('..');
     if (!defined('SM_PATH')) {
         define('SM_PATH', '../');
@@ -32,9 +32,8 @@ else if (file_exists('../../src/validate.php'))  {
     include_once(SM_PATH . 'src/validate.php');
 }
 
-// plugin includes
-require_once(SM_PATH . 'plugins/spamrule/config.php');
-require_once(SM_PATH . 'plugins/spamrule/lib.php');
+// load the compatibility plugin
+include_once(SM_PATH . 'plugins/compatibility/functions.php');
 
 global $SPAMRULE_OPTS, $action, $color;
 // When letting the user select from the CUSTOM group of filters,
@@ -48,6 +47,19 @@ if ($action != 'editlist') {
     displayPageHeader($color, '');
 }
 
+
+// we're internationalized, so bind gettext functions to our domain
+textdomain('spamrule');
+
+
+// load plugin configs and functions
+load_config('spamrule', array('config.php'));
+if (file_exists(SM_PATH . 'plugins/spamrule/config_local.php')) {
+    include_once(SM_PATH . 'plugins/spamrule/config_local.php');
+}
+require_once(SM_PATH . 'plugins/spamrule/lib.php');
+
+
 echo <<<EOjs
 
 <script language="JavaScript" type="text/javascript">
@@ -100,8 +112,7 @@ case 'subscribed':
     break;
 case 'editlist':
     sqgetGlobalVar('list', $list, SQ_FORM);
-    displayHtmlHeader(sr_gettext("Spam Rules:").
-                      ' '. $SPAMRULE_OPTS[$list]['title']);
+    displayHtmlHeader(_("Spam Rules:"). ' '. $SPAMRULE_OPTS[$list]['title']);
     switch ($list) {
     case 'allowed_senders':
     case 'blocked_senders':
@@ -120,9 +131,9 @@ case 'editlist':
     }
     break;
 default:
-    sr_print_header($SPAMRULE_OPTS['groups']['header'], 3);
+    sr_print_header($SPAMRULE_OPTS['groupsel']['header'], 3);
     sr_select_group();
-    sr_print_footer($SPAMRULE_OPTS['groups']['footer'], 3);
+    sr_print_footer($SPAMRULE_OPTS['groupsel']['footer'], 3);
     break;
 }
 
